@@ -19,6 +19,9 @@ get_rois <- function(){
                    lat = sapply(rois, function(x){tmp = x$lat; if(is.null(tmp)) tmp <- NA; tmp}),
                    lon = sapply(rois, function(x){tmp = x$lon; if(is.null(tmp)) tmp <- NA; tmp}),
                    roitype = sapply(rois, function(x){tmp = x$roitype; if(is.null(tmp)) tmp <- NA; tmp}),
+                   active = sapply(rois, function(x){tmp = x$active; if(is.null(tmp)) tmp <- NA; tmp}),
+                   show_link = sapply(rois, function(x){tmp = x$show_link; if(is.null(tmp)) tmp <- NA; tmp}),
+                   show_data_link = sapply(rois, function(x){tmp = x$show_data_link; if(is.null(tmp)) tmp <- NA; tmp}),
                    sequence_number = sapply(rois, function(x){tmp = x$sequence_number; if(is.null(tmp)) tmp <- NA; tmp}),
                    description = sapply(rois, function(x){tmp = x$description; if(is.null(tmp)) tmp <- NA; tmp}),
                    first_date = sapply(rois, function(x){tmp = x$first_date; if(is.null(tmp)) tmp <- NA; tmp}),
